# Core

```{eval-rst}
.. module:: annsel.core
```

## Selectors

```{eval-rst}
.. currentmodule:: annsel.core.expr
.. autosummary::
   :toctree: ../generated/

   col
   obs_names
   var_names
```

## Types

```{eval-rst}
.. currentmodule:: annsel.core.typing
.. autosummary::
   :toctree: ../generated/

   Predicate
   Predicates

```
